==> haskell-httpd-shed-0.4.1.0-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-httpd-shed.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: httpd-shed
version: 0.4.1.0
id: httpd-shed-0.4.1.0-CAyMx5jQzXA4IaXNcHbApg
key: httpd-shed-0.4.1.0-CAyMx5jQzXA4IaXNcHbApg
license: BSD-3-Clause
copyright: (c) 2009 Andy Gill
maintainer: Ganesh Sittampalam
author: Andy Gill, Brandon Moore, Henning Thielemann, John Van Enk.
synopsis: A simple web-server with an interact style API
description:
    This web server promotes a Request to IO Response function
    into a local web server. The user can decide how to interpret
    the requests, and the library is intended for implementing Ajax APIs.
category: Network, Web
abi: 99b8f67d400c63ccb10042349a7cb9d7
exposed: True
exposed-modules:
    Network.Shed.Httpd
import-dirs: /usr/lib/ghc-8.6.4/site-local/httpd-shed-0.4.1.0
library-dirs: /usr/lib/ghc-8.6.4/site-local/httpd-shed-0.4.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/httpd-shed-0.4.1.0
hs-libraries: HShttpd-shed-0.4.1.0-CAyMx5jQzXA4IaXNcHbApg
depends:
    base-4.12.0.0 network-2.8.0.0-79Coriq35AYDs1MobOTL51
    network-bsd-2.8.0.0-E9BgNM4lej9IcLQFfmLR8a
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
haddock-interfaces: /usr/share/doc/haskell-httpd-shed/html/httpd-shed.haddock
haddock-html: /usr/share/doc/haskell-httpd-shed/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-httpd-shed-0.4.1.0-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-httpd-shed.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: httpd-shed
version: 0.4.1.0
id: httpd-shed-0.4.1.0-8kVYm5Jv0ceIgAb8Ktg80j
key: httpd-shed-0.4.1.0-8kVYm5Jv0ceIgAb8Ktg80j
license: BSD-3-Clause
copyright: (c) 2009 Andy Gill
maintainer: Ganesh Sittampalam
author: Andy Gill, Brandon Moore, Henning Thielemann, John Van Enk.
synopsis: A simple web-server with an interact style API
description:
    This web server promotes a Request to IO Response function
    into a local web server. The user can decide how to interpret
    the requests, and the library is intended for implementing Ajax APIs.
category: Network, Web
abi: c45eecf0049f627b3b2340e562d65a8a
exposed: True
exposed-modules:
    Network.Shed.Httpd
import-dirs: /usr/lib/ghc-8.6.5/site-local/httpd-shed-0.4.1.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/httpd-shed-0.4.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/httpd-shed-0.4.1.0
hs-libraries: HShttpd-shed-0.4.1.0-8kVYm5Jv0ceIgAb8Ktg80j
depends:
    base-4.12.0.0 network-2.8.0.0-A0G1UJzDIGiEvzFah0DnI2
    network-bsd-2.8.0.0-GgInX1ED6yD69PM6i5jTY2
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
haddock-interfaces: /usr/share/doc/haskell-httpd-shed/html/httpd-shed.haddock
haddock-html: /usr/share/doc/haskell-httpd-shed/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
